/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import type { Router } from 'vue-router'

function setCommonGuard(router: Router) {
  const token = localStorage.getItem('Token') ?? sessionStorage.getItem('Token') ?? undefined

  router.beforeEach(async (to, _from, next) => {
    if (!token) {
      return next()
    }

    if (to.name === 'Clusters' && token) {
      return next({ name: 'Default' })
    }

    return next()
  })
}

function createRouterGuard(router: Router) {
  /** common guard */
  setCommonGuard(router)
}

export { createRouterGuard }
